# This file was automatically generated by SWIG
package Lab::VISA;
require Exporter;
require DynaLoader;
@ISA = qw(Exporter DynaLoader);
package Lab::VISA;
bootstrap Lab::VISA;
package Lab::VISA;
@EXPORT = qw( );
1;
